@@ -36,24 +36,26 @@ def main(args):
     # Good location to prepare plots
     logger.info('Building plots')
 
+    # Example data
+    raw_df = pd.DataFrame({
+        # as laid out in echarts docs for a dataset
+        'product': [
+            'Matcha Latte', 'Milk Tea', 'Cheese Cocoa', 'Walnut Brownie'],
+        '2015': [43.3, 83.1, 86.4, 72.4],
+        '2016': [85.8, 73.4, 65.2, 53.9],
+        '2017': [93.7, 55.1, 82.5, 39.1]
+    })
+    # how we'd likely normally have it
+    example_df = raw_df.melt(
+        id_vars=['product'], value_vars=['2015', '2016', '2017'],
+        var_name='year', value_name='sales')
+
     def example_plot(style="line") -> Plot:
         """Create example plot."""
-        df = pd.DataFrame({
-            # as laid out in echarts docs for a dataset
-            'product': [
-                'Matcha Latte', 'Milk Tea', 'Cheese Cocoa', 'Walnut Brownie'],
-            '2015': [43.3, 83.1, 86.4, 72.4],
-            '2016': [85.8, 73.4, 65.2, 53.9],
-            '2017': [93.7, 55.1, 82.5, 39.1]
-        })
-        # how we'd likely normally have it
-        df = df.melt(
-            id_vars=['product'], value_vars=['2015', '2016', '2017'],
-            var_name='year', value_name='sales')
         if style == "line":
-            plot = ezc.lineplot(data=df, x='year', y='sales', hue='product')
+            plot = ezc.lineplot(data=example_df, x='year', y='sales', hue='product')
         elif style == "scatter":
-            plot = ezc.scatterplot(data=df, x='year', y='sales', hue='product')
+            plot = ezc.scatterplot(data=example_df, x='year', y='sales', hue='product')
         elif style == 'histogram':
             hist_data = pd.DataFrame(
                         [np.random.normal(loc=10.0, size=1000),
@@ -65,7 +67,14 @@ def main(args):
             plot.xAxis.name = 'Read length'
             plot.yAxis.name = 'Number of reads'
         elif style == "bar":
-            plot = ezc.barplot(data=df, x='year', y='sales', hue='product')
+            plot = ezc.barplot(data=example_df, x='year', y='sales', hue='product')
+        elif style == "heatmap":
+            # make data a matrix like you would expect for a heatmap
+            df = raw_df.set_index([raw_df.columns[0]])
+            # set the names of the axes
+            df = df.rename_axis("Product")
+            df = df.rename_axis("Year", axis=1)
+            plot = ezc.heatmap(data=df)
         else:
             raise ValueError("Unknown plot style")
         plot.title = {"text": f"Example {style} chart"}
@@ -164,23 +173,36 @@ def main(args):
                 EZChart(example_plot(), 'epi2melabs')
             with tabs.add_dropdown_tab('Second'):
                 p("This is the second dropdown item.")
-                EZChart(example_plot('bar'), 'epi2melabs')
+                # set dodge=False for a stacked barplot
+                plot = ezc.barplot(
+                    data=example_df, x='year', y='sales', hue='product', dodge=False
+                )
+                EZChart(plot, 'epi2melabs')
 
     with report.add_section('Nextclade results', 'Nextclade', True):
         NextClade(nxt_json)
 
+    with report.add_section('Heatmap', 'Heatmap'):
+        EZChart(example_plot("heatmap"), 'epi2melabs')
+
     with report.add_section('Human Genome', 'Genome'):
         EZChart(
             ideogram(blocks='cytobands'),
             'epi2melabs', height="800px")
 
     with report.add_section('Table', 'Table'):
-        df = pd.DataFrame(np.random.random((4, 4))) * 10
-        df.columns = pd.MultiIndex.from_product(
-            [['sample1', 'sample2'], ['mapped', 'unmapped']])
-        df['chr'] = [1, 2, 3, 4]
-        df = df.set_index('chr', drop=True)
-        DataTable.from_pandas(df, use_index=True)
+        tabs = Tabs()
+        with tabs.add_tab('Table'):
+            df = pd.DataFrame(np.random.random((4, 4))) * 10
+            df.columns = pd.MultiIndex.from_product(
+                [['sample1', 'sample2'], ['mapped', 'unmapped']])
+            df['chr'] = [1, 2, 3, 4]
+            df = df.set_index('chr', drop=True)
+            DataTable.from_pandas(df, use_index=True)
+        with tabs.add_tab('Export'):
+            df_simple = pd.DataFrame(np.random.random((4, 2))) * 10
+            df_simple.columns = ['sample1', 'sample2']
+            DataTable.from_pandas(df_simple, export=True, file_name='samples')
 
     logger.info('Reticulating splines')
     report.write(args.output)
